@@ -3,7 +3,7 @@ import csv
 from operator import itemgetter
 from copy import deepcopy
 
-from .commons import run_requests
+from .commons import run_requests, structure_cardinality
 from ..services.services import Services
 
 
@@ -16,12 +16,18 @@ def convert_to_csv(
 ):
     # TODO: Make different csv output for multi card
     # Get requests result
-    (result, single_fieldnames, multi_fieldnames, default_cols, _) = run_requests(
+    result, single_fieldnames, multi_fieldnames, default_cols, _ = run_requests(
         workers, input_path, services
     )
     # fieldnames = set().union(single_fieldnames, multi_fieldnames)
     processed_dir_name = os.path.normpath(output_path).split(os.path.sep)[-1]
-    structure_result(result)
+
+    # Structure result
+    single_cardinality, multi_cardinality = structure_cardinality(
+        result, single_fieldnames, multi_fieldnames
+    )
+
+    structure_result(single_cardinality)
 
     with open(f"{processed_dir_name}_single_cardinality.csv", mode="w") as f:
         writer = csv.DictWriter(
@@ -31,8 +37,8 @@ def convert_to_csv(
             delimiter=";",
         )
         writer.writeheader()
-        for row in result:
-            writer.writerow(result[row])
+        for row in single_cardinality:
+            writer.writerow(single_cardinality[row])
 
 
 def structure_result(result):
